@@ -40,8 +40,8 @@ Please visit our Website: http://www.httrack.com
 #define HTTRACK_GLOBAL_DEFH
 
 // Version
-#define HTTRACK_VERSION      "3.40-2"
-#define HTTRACK_VERSIONID    "3.40.3"
+#define HTTRACK_VERSION      "3.32-3"
+#define HTTRACK_VERSIONID    "3.32.03"
 #define HTTRACK_AFF_VERSION  "3.x"
 //#define HTTRACK_AFF_WARNING  "This is a BETA release of WinHTTrack Website Copier ("HTTRACK_VERSION")\nPlease report any crashes, bugs or problems"
 
@@ -211,11 +211,6 @@ Please visit our Website: http://www.httrack.com
 #define HTS_USEOPENSSL 1
 #endif
 
-// utiliser mms://?
-#ifndef HTS_USEMMS
-#define HTS_USEMMS 1
-#endif
-
 #ifndef HTS_DLOPEN
 #define HTS_DLOPEN 1
 #endif
@@ -292,7 +287,7 @@ Please visit our Website: http://www.httrack.com
 #endif
 
 /* Copyright (C) Xavier Roche and other contributors */
-#define HTTRACK_AFF_AUTHORS "[XR&CO'2006]"
+#define HTTRACK_AFF_AUTHORS "[XR&CO'2004]"
 #define HTS_DEFAULT_FOOTER "<!-- Mirrored from %s%s by HTTrack Website Copier/"HTTRACK_AFF_VERSION" "HTTRACK_AFF_AUTHORS", %s -->"
 #define HTTRACK_WEB "http://www.httrack.com"
 #define HTS_UPDATE_WEBSITE "http://www.httrack.com/update.php3?Product=HTTrack&Version="HTTRACK_VERSIONID"&VersionStr="HTTRACK_VERSION"&Platform=%d&Language=%s"
@@ -471,11 +466,11 @@ typedef int INTsys;
 //#define HTS_TRACE_MALLOC
 #ifdef HTS_TRACE_MALLOC
 typedef unsigned long int t_htsboundary;
-typedef struct mlink {
+typedef struct _mlink {
   char* adr;
   int len;
   int id;
-  struct mlink* next;
+  struct _mlink* next;
 } mlink;
 static const t_htsboundary htsboundary = 0xDEADBEEF;
 #endif
