@@ -56,12 +56,12 @@ Please visit our Website: http://www.httrack.com
 
 // Portable directory find functions
 #ifdef _WIN32
-typedef struct find_handle_struct {
+typedef struct {
   WIN32_FIND_DATAA hdata;
   HANDLE handle;
 } find_handle_struct;
 #else
-typedef struct find_handle_struct {
+typedef struct {
   DIR * hdir;
   struct dirent* dirp;
   struct stat filestat;
@@ -87,7 +87,6 @@ void long_to_83(int mode,char* n83,char* save);
 void longfile_to_83(int mode,char* n83,char* save);
 HTS_INLINE int __rech_tageq(const char* adr,const char* s);
 HTS_INLINE int __rech_tageqbegdigits(const char* adr,const char* s);
-HTS_INLINE int rech_tageq_all(const char* adr, const char* s);
 #define rech_tageq(adr,s) \
   ( \
     ( (*((adr)-1)=='<') || (is_space(*((adr)-1))) ) ? \
