@@ -81,7 +81,7 @@ Please visit our Website: http://www.httrack.com
 
 static PTHREAD_LOCK_TYPE refreshMutex;
 
-static int help_server(char* dest_path, int defaultPort);
+static int help_server(char* dest_path);
 extern int commandRunning;
 extern int commandEnd;
 extern int commandReturn;
@@ -97,7 +97,6 @@ int main(int argc, char* argv[])
 {
   int i;
   int ret = 0;
-  int defaultPort = 0;
   printf("Initialzing the server..\n");
 
 #ifdef _WIN32
@@ -120,7 +119,7 @@ int main(int argc, char* argv[])
 
   if (argc < 2 || (argc % 2) != 0) {
     fprintf(stderr, "** Warning: use the webhttrack frontend if available\n");
-    fprintf(stderr, "usage: %s [--port <port>] <path-to-html-root-dir> [key value [key value]..]\n", argv[0]);
+    fprintf(stderr, "usage: %s <path-to-html-root-dir> [key value [key value]..]\n", argv[0]);
     fprintf(stderr, "example: %s /usr/share/httrack/\n", argv[0]);
     return 1;
   }
@@ -189,15 +188,8 @@ int main(int argc, char* argv[])
   }
 
   /* set commandline keys */
-	for(i = 2 ; i < argc ; i += 2) {
-		if (strcmp(argv[i], "--port") == 0) {
-			if (sscanf(argv[i + 1], "%d", &defaultPort) != 1 || defaultPort < 0 || defaultPort >= 65535 ) {
-				fprintf(stderr, "couldn't set the port number to %d\n", argv[i + 1]);
-				return -1;
-			}
-		} else {
-			smallserver_setkey(argv[i], argv[i + 1]);
-		}
+  for(i = 2 ; i < argc ; i += 2) {
+    smallserver_setkey(argv[i], argv[i + 1]);
   }
 
   /* sigpipe */
@@ -206,9 +198,8 @@ int main(int argc, char* argv[])
 #endif
 
   /* launch */
-  ret = help_server(argv[1], defaultPort);
+  ret = help_server(argv[1]);
 
-  htsthread_wait();
   hts_uninit();
 
 #ifdef _WIN32
@@ -219,7 +210,7 @@ int main(int argc, char* argv[])
 }
 
 static int webhttrack_runmain(int argc, char** argv);
-static PTHREAD_TYPE PTHREAD_TYPE_FNC back_launch_cmd( void* pP ) {
+static PTHREAD_TYPE back_launch_cmd( void* pP ) {
   char* cmd = (char*) pP;
   char** argv = (char**) malloct(1024 * sizeof(char*));
   int argc = 0;
@@ -276,7 +267,7 @@ static PTHREAD_TYPE PTHREAD_TYPE_FNC back_launch_cmd( void* pP ) {
 
 void webhttrack_main(char* cmd) {
   commandRunning = 1;
-  (void)hts_newthread(back_launch_cmd, 0, (void*) strdup(cmd));
+  _beginthread(back_launch_cmd, 0, (void*) strdup(cmd));
 }
 
 /* Internal locking */
@@ -293,32 +284,27 @@ static int webhttrack_runmain(int argc, char** argv) {
   htswrap_add("start",htsshow_start);
   htswrap_add("change-options",htsshow_chopt);
   htswrap_add("end",htsshow_end);
-  htswrap_add("preprocess-html",htsshow_preprocesshtml);
   htswrap_add("check-html",htsshow_checkhtml);
   htswrap_add("loop",htsshow_loop);
   htswrap_add("query",htsshow_query);
   htswrap_add("query2",htsshow_query2);
   htswrap_add("query3",htsshow_query3);
   htswrap_add("check-link",htsshow_check);
-  htswrap_add("check-mime",htsshow_check_mime);
   htswrap_add("pause",htsshow_pause);
   htswrap_add("save-file",htsshow_filesave);
-  htswrap_add("save-file2",htsshow_filesave2);
   htswrap_add("link-detected",htsshow_linkdetected);
-  htswrap_add("link-detected2",htsshow_linkdetected2);
   htswrap_add("transfer-status",htsshow_xfrstatus);
   htswrap_add("save-name",htsshow_savename);
-  htsthread_wait_n(1);
   hts_uninit();
   return hts_main(argc,argv);
  
 }
 
-static int help_server(char* dest_path, int defaultPort) {
+static int help_server(char* dest_path) {
   int returncode = 0;
   char adr_prox[HTS_URLMAXSIZE*2];
   int port_prox;
-  T_SOC soc=smallserver_init_std(&port_prox, adr_prox, defaultPort);
+  T_SOC soc=smallserver_init_std(&port_prox,adr_prox);
   if (soc!=INVALID_SOCKET) {
     char url[HTS_URLMAXSIZE*2];
     char method[32];
@@ -337,7 +323,7 @@ static int help_server(char* dest_path, int defaultPort) {
     fflush(stderr);
     //
     if (!smallserver(soc,url,method,data,dest_path)) {
-      fprintf(stderr, "Unable to create the server: %s\n", strerror(errno));
+      fprintf(stderr, "Unable to create the server\n");
 #ifdef _WIN32
       closesocket(soc);
 #else
@@ -375,9 +361,6 @@ int __cdecl htsshow_chopt(httrackp* opt) {
 int  __cdecl htsshow_end(void) { 
   return 1; 
 }
-int __cdecl htsshow_preprocesshtml(char** html,int* len,char* url_adresse,char* url_fichier) {
-  return 1;
-}
 int __cdecl htsshow_checkhtml(char* html,int len,char* url_adresse,char* url_fichier) {
   return 1;
 }
@@ -510,27 +493,17 @@ int __cdecl htsshow_loop(lien_back* back,int back_max,int back_index,int lien_n,
                   strcpybuff(StatsBuffer[index].state,"request"); ok=1;
                 }
                 else if (back[i].status==100) {
-									strcpybuff(StatsBuffer[index].state,"connect"); ok=1;
-								}
-								else if (back[i].status==101) {
-									strcpybuff(StatsBuffer[index].state,"search"); ok=1;
-								}
-								else if (back[i].status==1000) {    // ohh le beau ftp
-									char proto[] = "ftp";
-									if (back[i].url_adr[0]) {
-										char* ep = strchr(back[i].url_adr, ':');
-										char* eps = strchr(back[i].url_adr, '/');
-										int count;
-										if (ep != NULL && ep < eps && (count = (ep - back[i].url_adr) ) < 4) {
-											proto[0] = '\0';
-											strncat(proto, back[i].url_adr, count);
-										}
-									}
-									sprintf(StatsBuffer[index].state,"%s: %s",proto,back[i].info); ok=1;
-								}
-								break;
-							default:
-								if (back[i].status==0) {  // prt
+                  strcpybuff(StatsBuffer[index].state,"connect"); ok=1;
+                }
+                else if (back[i].status==101) {
+                  strcpybuff(StatsBuffer[index].state,"search"); ok=1;
+                }
+                else if (back[i].status==1000) {    // ohh le beau ftp
+                  sprintf(StatsBuffer[index].state,"ftp: %s",back[i].info); ok=1;
+                }
+                break;
+              default:
+                if (back[i].status==0) {  // prt
                   if ((back[i].r.statuscode==200)) {
                     strcpybuff(StatsBuffer[index].state,"ready"); ok=1;
                   }
@@ -619,15 +592,6 @@ int __cdecl htsshow_loop(lien_back* back,int back_max,int back_index,int lien_n,
           case 2:
             sprintf(tmp, "purging files");
             break;
-          case 3:
-            sprintf(tmp, "loading cache");
-            break;
-          case 4:
-            sprintf(tmp, "waiting (scheduler)");
-            break;
-          case 5:
-            sprintf(tmp, "waiting (throttle)");
-            break;
           }
           smallserver_setkey("info.currentjob", tmp);
         }
@@ -675,21 +639,13 @@ char* __cdecl htsshow_query3(char* question) {
 int __cdecl htsshow_check(char* adr,char* fil,int status) {
   return -1;
 }
-int __cdecl htsshow_check_mime(char* adr,char* fil,char* mime,int status) {
-  return -1;
-}
 void __cdecl htsshow_pause(char* lockfile) {
 }
 void __cdecl htsshow_filesave(char* file) {
 }
-void  __cdecl htsshow_filesave2(char* adr, char* fil, char* save, int is_new, int is_modified,int not_updated) {
-}
 int __cdecl htsshow_linkdetected(char* link) {
   return 1;
 }
-int __cdecl htsshow_linkdetected2(char* link, char* start_tag) {
-  return 1;
-}
 int __cdecl htsshow_xfrstatus(lien_back* back) {
   return 1;
 }
